import {
  MarkdownParser,
  MarkdownSerializer
} from "./chunk-52UWRQN5.js";
import {
  defaultTokenizers
} from "./chunk-TKCMMCGO.js";

// src/markdown.ts
function createTokenCollection(type) {
  return {
    type,
    parsing: {},
    toMarkdown: {}
  };
}
function processTokens(collection, key, value, type) {
  const parse = value.parseMarkdown;
  if (parse) {
    for (const [key2, value2] of Object.entries(parse)) {
      if (collection.parsing[key2]) {
        throw new Error(`Duplicate ${type} parsing token found: ${key2}`);
      }
      collection.parsing[key2] = value2;
    }
  }
  const toMarkdown = value.toMarkdown;
  if (toMarkdown) {
    if (collection.toMarkdown[key]) {
      throw new Error(`Duplicate ${type} toMarkdown token found: ${key}`);
    }
    collection.toMarkdown[key] = toMarkdown;
  }
}
function markdownLoader(items, schema, tokenizers = defaultTokenizers, serializerOptions) {
  const nodeTokens = createTokenCollection("node");
  const markTokens = createTokenCollection("mark");
  for (const item of items) {
    if (item.markdown?.nodes) {
      for (const [key, value] of Object.entries(item.markdown.nodes)) {
        processTokens(nodeTokens, key, value, "node");
      }
    }
    if (item.markdown?.marks) {
      for (const [key, value] of Object.entries(item.markdown.marks)) {
        processTokens(markTokens, key, value, "mark");
      }
    }
  }
  for (const key of Object.keys(nodeTokens.parsing)) {
    if (markTokens.parsing[key]) {
      throw new Error(
        `Token key "${key}" exists in both nodes and marks parsing tokens`
      );
    }
  }
  return {
    parser: new MarkdownParser(schema, tokenizers, {
      ...nodeTokens.parsing,
      ...markTokens.parsing
    }),
    serializer: new MarkdownSerializer(
      nodeTokens.toMarkdown,
      markTokens.toMarkdown,
      serializerOptions
    )
  };
}

export {
  markdownLoader
};
